@@ -48,7 +48,7 @@ class UntetheredFrame(BaseFrame):
         #                    lang.getstr("measurement.untethered"),
         #                    style=wx.DEFAULT_FRAME_STYLE | wx.TAB_TRAVERSAL,
         #                    name="untetheredframe")
-        super(UntetheredFrame, self).__init__(
+        BaseFrame.__init__(
             self,
             parent,
             wx.ID_ANY,
@@ -108,7 +108,8 @@ class UntetheredFrame(BaseFrame):
         )
         self.measure_auto_cb.SetForegroundColour(FGCOLOUR)
         self.measure_auto_cb.Bind(wx.EVT_CHECKBOX, self.measure_auto_ctrl_handler)
-        sizer.Add(self.measure_auto_cb, 0, wx.ALIGN_CENTER_VERTICAL | wx.ALIGN_RIGHT)
+        # only vertical alignment flags can be used with a horizontal sizer
+        sizer.Add(self.measure_auto_cb, 0, wx.ALIGN_CENTER_VERTICAL)
         panelsizer.Add(sizer, 0, wx.BOTTOM | wx.EXPAND, border=8)
         sizer = wx.BoxSizer(wx.HORIZONTAL)
         self.measure_btn = FlatShadedButton(
@@ -309,7 +310,7 @@ class UntetheredFrame(BaseFrame):
 
     def finish_btn_handler(self, event):
         self.finish_btn.Disable()
-        self.cgats[0].type = "CTI3"
+        self.cgats[0].type = b"CTI3"
         self.cgats[0].add_keyword("COLOR_REP", "RGB_XYZ")
         if self.white_XYZ[1] > 0:
             # Normalize to Y = 100
@@ -328,10 +329,10 @@ class UntetheredFrame(BaseFrame):
             self.cgats[0].remove_keyword("APPROX_WHITE_POINT")
         # Remove L*a*b* from DATA_FORMAT if present
         for i, label in reversed(list(self.cgats[0].DATA_FORMAT.items())):
-            if label.startswith("LAB_"):
+            if label.startswith(b"LAB_"):
                 self.cgats[0].DATA_FORMAT.pop(i)
         # Add XYZ to DATA_FORMAT if not yet present
-        for label in ("XYZ_X", "XYZ_Y", "XYZ_Z"):
+        for label in (b"XYZ_X", b"XYZ_Y", b"XYZ_Z"):
             if label not in list(self.cgats[0].DATA_FORMAT.values()):
                 self.cgats[0].DATA_FORMAT.add_data((label,))
         self.cgats[0].write(os.path.splitext(self.cgats.filename)[0] + ".ti3")
@@ -514,10 +515,12 @@ class UntetheredFrame(BaseFrame):
             )
             if not XYZ:
                 return
+            def is_white(r):
+                return r["RGB_R"] == 100 and r["RGB_G"] == 100 and r["RGB_B"] == 100
+
             XYZ = [float(v) for v in XYZ.groups()]
             row = self.cgats[0].DATA[self.index]
-            if row["RGB_R"] == 100 and row["RGB_G"] == 100 and row["RGB_B"] == 100:
-                # White
+            if is_white(row):
                 if XYZ[1] > 0:
                     self.cgats[0].add_keyword(
                         "LUMINANCE_XYZ_CDM2", "%.6f %.6f %.6f" % tuple(XYZ)
@@ -532,10 +535,12 @@ class UntetheredFrame(BaseFrame):
                 print("Delta E to last recorded Lab: %.4f" % delta["E"])
                 print("Abs. delta L to last recorded Lab: %.4f" % abs(delta["L"]))
                 print("Abs. delta C to last recorded Lab: %.4f" % abs(delta["C"]))
-            if delta["E"] > getcfg("untethered.min_delta") or (
+            consecutive_white_patch = self.index and is_white(row) and is_white(self.cgats[0].DATA[self.index - 1])
+            measurement_exceeds_delta = delta["E"] > getcfg("untethered.min_delta") or (
                 abs(delta["L"]) > getcfg("untethered.min_delta.lightness")
                 and abs(delta["C"]) < getcfg("untethered.max_delta.chroma")
-            ):
+            )
+            if consecutive_white_patch or measurement_exceeds_delta:
                 self.measure_count += 1
                 if self.measure_count == 2:
                     if getcfg("measurement.play_sound"):
@@ -544,34 +549,30 @@ class UntetheredFrame(BaseFrame):
                     # Reset row label
                     self.grid.SetRowLabelValue(self.index, "%i" % (self.index + 1))
                     # Update CGATS
-                    query = self.cgats[0].queryi(
+                    query = self.cgats[0].queryi1(
                         {
                             "RGB_R": row["RGB_R"],
                             "RGB_G": row["RGB_G"],
                             "RGB_B": row["RGB_B"],
+                            "SAMPLE_ID": row["SAMPLE_ID"]
                         }
                     )
-                    for i in query:
-                        index = query[i].SAMPLE_ID - 1
+                    if query:
+                        index = query.SAMPLE_ID - 1
                         if index not in self.measured:
                             self.measured.append(index)
-                        if index == self.index + 1:
-                            # Increment the index if we have consecutive patches
-                            self.index = index
-                        query[i]["XYZ_X"], query[i]["XYZ_Y"], query[i]["XYZ_Z"] = XYZ
+                        query["XYZ_X"], query["XYZ_Y"], query["XYZ_Z"] = XYZ
                     if getcfg("untethered.measure.auto"):
                         self.show_RGB(False, False)
                     self.show_XYZ()
                     Lab, color = self.get_Lab_RGB()
-                    for i in query:
-                        row = query[i]
-                        self.grid.SetCellBackgroundColour(
-                            query[i].SAMPLE_ID - 1, 4, wx.Colour(*color)
+                    self.grid.SetCellBackgroundColour(
+                        query.SAMPLE_ID - 1, 4, wx.Colour(*color)
+                    )
+                    for j in range(3):
+                        self.grid.SetCellValue(
+                            query.SAMPLE_ID - 1, 5 + j, "%.2f" % Lab[j]
                         )
-                        for j in range(3):
-                            self.grid.SetCellValue(
-                                query[i].SAMPLE_ID - 1, 5 + j, "%.2f" % Lab[j]
-                            )
                     self.grid.MakeCellVisible(self.index, 0)
                     self.grid.ForceRefresh()
                     if len(self.measured) == data_len:
